==> gimp-1.3.12.tar.bz2: gimp-1.3.12/app/paint/gimpdodgeburn.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_DODGE_BURN_H__
#define __GIMP_DODGE_BURN_H__


#include "gimppaintcore.h"
#include "gimppaintoptions.h"


#define GIMP_TYPE_DODGE_BURN            (gimp_dodge_burn_get_type ())
#define GIMP_DODGE_BURN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DODGE_BURN, GimpDodgeBurn))
#define GIMP_IS_DODGE_BURN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DODGE_BURN))
#define GIMP_DODGE_BURN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DODGEBURN, GimpDodgeBurnClass))
#define GIMP_IS_DODGE_BURN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DODGE_BURN))


typedef struct _GimpDodgeBurn      GimpDodgeBurn;
typedef struct _GimpDodgeBurnClass GimpDodgeBurnClass;

struct _GimpDodgeBurn
{
  GimpPaintCore  parent_instance;

  GimpLut       *lut;
};

struct _GimpDodgeBurnClass
{
  GimpPaintCoreClass parent_class;
};


void    gimp_dodge_burn_register (Gimp                      *gimp,
                                  GimpPaintRegisterCallback  callback);

GType   gimp_dodge_burn_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_DODGE_BURN_H__  */

==> gimp-2.3.10.tar.bz2: gimp-2.3.10/app/paint/gimpdodgeburn.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_DODGE_BURN_H__
#define __GIMP_DODGE_BURN_H__


#include "gimpbrushcore.h"


#define GIMP_TYPE_DODGE_BURN            (gimp_dodge_burn_get_type ())
#define GIMP_DODGE_BURN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DODGE_BURN, GimpDodgeBurn))
#define GIMP_IS_DODGE_BURN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DODGE_BURN))
#define GIMP_DODGE_BURN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DODGEBURN, GimpDodgeBurnClass))
#define GIMP_IS_DODGE_BURN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DODGE_BURN))


typedef struct _GimpDodgeBurn      GimpDodgeBurn;
typedef struct _GimpDodgeBurnClass GimpDodgeBurnClass;

struct _GimpDodgeBurn
{
  GimpBrushCore  parent_instance;

  GimpLut       *lut;
};

struct _GimpDodgeBurnClass
{
  GimpBrushCoreClass parent_class;
};


void    gimp_dodge_burn_register (Gimp                      *gimp,
                                  GimpPaintRegisterCallback  callback);

GType   gimp_dodge_burn_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_DODGE_BURN_H__  */
